==> rest-sdk-0.1.0-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/connectormodel/ConnectorOperation.java <==
/*
 * (c) 2003-2020 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.connectormodel;

import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.parameter.Parameter;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.security.ConnectorSecurityScheme;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.type.TypeDefinition;

import java.util.List;

import static org.apache.commons.lang3.StringUtils.isNotBlank;
import static com.mulesoft.connectivity.rest.sdk.internal.webapi.util.OperationNamingUtils.buildCanonicalOperationName;
import static com.mulesoft.connectivity.rest.sdk.internal.webapi.util.XmlUtils.getXmlName;


public class ConnectorOperation {

  /**
   * XML name used to identify this operation internally.
   */
  private final String internalName;

  /**
   * User friendly name for this parameter
   */
  private final String displayName;

  private final String description;
  /**
   * Mapping key name defined for a multiple base path type.
   */
  private final String alternativeBaseUri;
  private final String path;
  private final HTTPMethod httpMethod;
  private final String pagination;
  private final List<Parameter> uriParameters;
  private final List<Parameter> queryParameters;
  private final List<Parameter> headers;

  private final TypeDefinition inputMetadata;
  private final TypeDefinition outputMetadata;

  private final Boolean skipOutputTypeValidation;
  private final Boolean voidOperation;
  private final QueryParamArrayFormat queryParamArrayFormat;

  private final List<ConnectorSecurityScheme> securitySchemes;

  public ConnectorOperation(String displayName,
                            String description,
                            String path,
                            HTTPMethod httpMethod,
                            List<Parameter> uriParameters,
                            List<Parameter> queryParameters,
                            List<Parameter> headers,
                            TypeDefinition inputMetadata,
                            TypeDefinition outputMetadata,
                            List<ConnectorSecurityScheme> securitySchemes,
                            String alternativeBaseUri,
                            String pagination,
                            Boolean skipOutputTypeValidation,
                            Boolean voidOperation,
                            QueryParamArrayFormat queryParamArrayFormat) {

    this.internalName = getXmlName(buildCanonicalOperationName(httpMethod, path));
    this.displayName = displayName;
    this.description = description;
    this.path = path;
    this.httpMethod = httpMethod;

    this.uriParameters = uriParameters;
    this.queryParameters = queryParameters;
    this.headers = headers;
    this.inputMetadata = inputMetadata;
    this.outputMetadata = outputMetadata;
    this.securitySchemes = securitySchemes;

    this.alternativeBaseUri = alternativeBaseUri;
    this.pagination = pagination;

    this.skipOutputTypeValidation = skipOutputTypeValidation;
    this.voidOperation = voidOperation;
    this.queryParamArrayFormat = queryParamArrayFormat;
  }

  public List<Parameter> getQueryParameters() {
    return queryParameters;
  }

  public List<Parameter> getUriParameters() {
    return uriParameters;
  }

  public List<Parameter> getHeaders() {
    return headers;
  }

  public String getHttpMethod() {
    return httpMethod.toString().toLowerCase();
  }

  public String getPath() {
    return path;
  }

  public String getDescription() {
    return description;
  }

  public TypeDefinition getInputMetadata() {
    return inputMetadata;
  }

  public TypeDefinition getOutputMetadata() {
    return outputMetadata;
  }

  public List<ConnectorSecurityScheme> getSecuritySchemes() {
    return securitySchemes;
  }

  public String getInternalName() {
    return internalName;
  }

  public String getDisplayName() {
    return displayName;
  }

  public String getAlternativeBaseUri() {
    return alternativeBaseUri;
  }

  public String getPagination() {
    return pagination;
  }

  public boolean hasPagination() {
    return isNotBlank(this.pagination);
  }

  public Boolean getSkipOutputTypeValidation() {
    return skipOutputTypeValidation;
  }

  public Boolean getVoidOperation() {
    return voidOperation;
  }

  public QueryParamArrayFormat getQueryParamArrayFormat() {
    return queryParamArrayFormat;
  }
}

==> rest-sdk-0.1.1-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/connectormodel/ConnectorOperation.java <==
/*
 * (c) 2003-2020 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.connectormodel;

import static com.mulesoft.connectivity.rest.sdk.internal.webapi.util.OperationNamingUtils.buildCanonicalOperationName;
import static com.mulesoft.connectivity.rest.sdk.internal.webapi.util.XmlUtils.getXmlName;
import static org.apache.commons.lang3.StringUtils.isNotBlank;

import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.parameter.Parameter;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.security.ConnectorSecurityScheme;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.type.TypeDefinition;

import java.util.List;


public class ConnectorOperation {

  /**
   * XML name used to identify this operation internally.
   */
  private final String internalName;

  /**
   * User friendly name for this parameter
   */
  private final String displayName;

  private final String description;
  /**
   * Mapping key name defined for a multiple base path type.
   */
  private final String alternativeBaseUri;
  private final String path;
  private final HTTPMethod httpMethod;
  private final String pagination;
  private final List<Parameter> uriParameters;
  private final List<Parameter> queryParameters;
  private final List<Parameter> headers;

  private final TypeDefinition inputMetadata;
  private final TypeDefinition outputMetadata;

  private final Boolean skipOutputTypeValidation;
  private final Boolean voidOperation;
  private final QueryParamArrayFormat queryParamArrayFormat;

  /**
   * This field indicates if the operation is not meant to be generated in the generated connector.
   */
  private final boolean isIgnored;

  private final List<ConnectorSecurityScheme> securitySchemes;
  private boolean sampleData;

  public ConnectorOperation(String displayName,
                            String description,
                            String path,
                            HTTPMethod httpMethod,
                            List<Parameter> uriParameters,
                            List<Parameter> queryParameters,
                            List<Parameter> headers,
                            TypeDefinition inputMetadata,
                            TypeDefinition outputMetadata,
                            List<ConnectorSecurityScheme> securitySchemes,
                            String alternativeBaseUri,
                            String pagination,
                            Boolean skipOutputTypeValidation,
                            Boolean voidOperation,
                            QueryParamArrayFormat queryParamArrayFormat,
                            boolean isIgnored) {

    this.internalName = getXmlName(buildCanonicalOperationName(httpMethod, path));
    this.displayName = displayName;
    this.description = description;
    this.path = path;
    this.httpMethod = httpMethod;

    this.uriParameters = uriParameters;
    this.queryParameters = queryParameters;
    this.headers = headers;
    this.inputMetadata = inputMetadata;
    this.outputMetadata = outputMetadata;
    this.securitySchemes = securitySchemes;

    this.alternativeBaseUri = alternativeBaseUri;
    this.pagination = pagination;

    this.skipOutputTypeValidation = skipOutputTypeValidation;
    this.voidOperation = voidOperation;
    this.queryParamArrayFormat = queryParamArrayFormat;

    this.isIgnored = isIgnored;
  }

  public List<Parameter> getQueryParameters() {
    return queryParameters;
  }

  public List<Parameter> getUriParameters() {
    return uriParameters;
  }

  public List<Parameter> getHeaders() {
    return headers;
  }

  public String getHttpMethod() {
    return httpMethod.toString().toLowerCase();
  }

  public String getPath() {
    return path;
  }

  public String getDescription() {
    return description;
  }

  public TypeDefinition getInputMetadata() {
    return inputMetadata;
  }

  public TypeDefinition getOutputMetadata() {
    return outputMetadata;
  }

  public List<ConnectorSecurityScheme> getSecuritySchemes() {
    return securitySchemes;
  }

  public String getInternalName() {
    return internalName;
  }

  public String getDisplayName() {
    return displayName;
  }

  public String getAlternativeBaseUri() {
    return alternativeBaseUri;
  }

  public String getPagination() {
    return pagination;
  }

  public boolean hasPagination() {
    return isNotBlank(this.pagination);
  }

  public Boolean getSkipOutputTypeValidation() {
    return skipOutputTypeValidation;
  }

  public Boolean getVoidOperation() {
    return voidOperation;
  }

  public QueryParamArrayFormat getQueryParamArrayFormat() {
    return queryParamArrayFormat;
  }

  public boolean isIgnored() {
    return isIgnored;
  }

  public boolean getSampleData() {
    return sampleData;
  }

  public void setSampleData(boolean sampleData) {
    this.sampleData = sampleData;
  }
}
